[EDT][PATCH 1/11] Typo fix : begining -> beginning

Maninder Singh maninder1.s at samsung.com
Thu May 21 03:41:32 UTC 2015


EP-E9D7571734A347E2ADA07C4134AB97EA
Hi,

Subject: [PATCH 01/11] typo fix

begining -> beginning

Signed-off-by: Maninder Singh <maninder1.s at samsung.com>
Reviewed-by: Akhilesh Kumar <akhilesh.k at samsung.com>
---
 editors/diff.c |    2 +-
 editors/vi.c   |   10 +++++-----
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/editors/diff.c b/editors/diff.c
index c3ad31b..cf14b1d 100644
--- a/editors/diff.c
+++ b/editors/diff.c
@@ -363,7 +363,7 @@ static void stone(const int *a, int n, const int *b, int *J, int pref)
 }
 
 struct line {
-	/* 'serial' is not used in the begining, so we reuse it
+	/* 'serial' is not used in the beginning, so we reuse it
 	 * to store line offsets, thus reducing memory pressure
 	 */
 	union {
diff --git a/editors/vi.c b/editors/vi.c
index 2e4f7fc..c8c7b32 100644
--- a/editors/vi.c
+++ b/editors/vi.c
@@ -501,7 +501,7 @@ static char *prev_line(char *);	// return pointer to prev line B-o-l
 static char *next_line(char *);	// return pointer to next line B-o-l
 static char *end_screen(void);	// get pointer to last char on screen
 static int count_lines(char *, char *);	// count line from start to stop
-static char *find_line(int);	// find begining of line #li
+static char *find_line(int);	// find beginning of line #li
 static char *move_to_col(char *, int);	// move "p" to column l
 static void dot_left(void);	// move dot left- dont leave line
 static void dot_right(void);	// move dot right- dont leave line
@@ -1684,10 +1684,10 @@ static char *dollar_line(char *p) // return pointer to just before NL line
 
 static char *prev_line(char *p) // return pointer first char prev line
 {
-	p = begin_line(p);	// goto begining of cur line
+	p = begin_line(p);	// goto beginning of cur line
 	if (p > text && p[-1] == '\n')
 		p--;			// step to prev line
-	p = begin_line(p);	// goto begining of prev line
+	p = begin_line(p);	// goto beginning of prev line
 	return p;
 }
 
@@ -1735,7 +1735,7 @@ static int count_lines(char *start, char *stop)
 	return cnt;
 }
 
-static char *find_line(int li)	// find begining of line #li
+static char *find_line(int li)	// find beginning of line #li
 {
 	char *q;
 
@@ -3844,7 +3844,7 @@ static void do_cmd(int c)
 		}
 		break;
 #endif /* FEATURE_VI_SEARCH */
-	case '0':			// 0- goto begining of line
+	case '0':			// 0- goto beginning of line
 	case '1':			// 1-
 	case '2':			// 2-
 	case '3':			// 3-
-- 
1.7.1

Thanks 
Maninder Singh


More information about the busybox mailing list